@@ -43,6 +43,9 @@ struct cxl_afu_h {
 	size_t mmio_size;
 	int fd_errbuff; /* fd to the afu_err_buff */
 	size_t errbuff_size;
+#if defined CXL_START_WORK_TID
+	int pid;
+#endif
 };
 
 int cxl_get_dev(struct cxl_afu_h *afu, long *majorp, long *minorp);
