@@ -54,6 +54,7 @@ enum cxl_sysfs_attr {
 	IMAGE_LOADED,
 	PSL_REVISION,
 	PSL_TIMEBASE_SYNCED,
+	TUNNELED_OPS_SUPPORTED,
 
 	/* Add new attrs above this */
 	CXL_ATTR_MAX
@@ -94,6 +95,7 @@ static struct cxl_sysfs_entry sysfs_entry[CXL_ATTR_MAX] = {
 	[IMAGE_LOADED] = { "image_loaded", scan_image, 1 },
 	[PSL_REVISION] = { "psl_revision", scan_int, 1 },
 	[PSL_TIMEBASE_SYNCED] = { "psl_timebase_synced", scan_int, 1 },
+	[TUNNELED_OPS_SUPPORTED] = { "tunneled_ops_supported", scan_int, 1 },
 };
 
 #define OUT_OF_RANGE(attr) ((attr) < 0 || (attr) >= CXL_ATTR_MAX || \
@@ -436,6 +438,11 @@ int cxl_get_psl_timebase_synced(struct cxl_adapter_h *adapter, long *valp)
 	return read_sysfs_adapter(adapter, PSL_TIMEBASE_SYNCED, valp, NULL);
 }
 
+int cxl_get_tunneled_ops_supported(struct cxl_adapter_h *adapter, long *valp)
+{
+	return read_sysfs_adapter(adapter, TUNNELED_OPS_SUPPORTED, valp, NULL);
+}
+
 static int write_sysfs_str(char *path, enum cxl_sysfs_attr attr, char *str)
 {
 	char *attr_name;
